# Generated by Django 4.2.8 on 2024-01-29 11:19

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('wagtailcore', '0089_log_entry_data_json_null_to_object'),
    ]

    operations = [
        migrations.CreateModel(
            name='Feedback',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('positive', models.BooleanField(help_text='Whether the feedback is positive or negative.', verbose_name='Positive')),
                ('message', models.TextField(help_text='The message of the feedback.', null=True, verbose_name='Message')),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='The time the feedback was created.', verbose_name='Created At')),
                ('ip_address', models.GenericIPAddressField(blank=True, help_text='The IP address of the feedback.', null=True, verbose_name='IP Address')),
                ('page', models.ForeignKey(help_text='The page the feedback is for.', on_delete=django.db.models.deletion.CASCADE, related_name='+', to='wagtailcore.page', verbose_name='Page')),
            ],
            options={
                'verbose_name': 'Feedback',
                'verbose_name_plural': 'Feedback',
                'ordering': ['-created_at'],
            },
        ),
    ]
